/* 
  Hole.m

  Barry McMullin <mcmullin@eeng.dcu.ie>
  03-OCT-1996

*/

#import "Hole.h"

@implementation Hole

static double holeMobilityFactor = 1.0;
static Color holeColor;
/*
  See docs in Particle.m
*/

+(void) setClassMobilityFactor: (double) inMobilityFactor {
  holeMobilityFactor = inMobilityFactor;
}

+(double) getClassMobilityFactor {
  return(holeMobilityFactor);
}

+(void) setClassColor: (Color) color {
  holeColor = color;
}

+(Color) getClassColor {
  return(holeColor);
}

-drawSelfOn: (id <Raster>) r {
  /* Raster is cleared anyway: so we don't have to
     *do* anything to redraw a hole... */

  return self;
}

@end
